summaryrefslogtreecommitdiffstats
path: root/src/library/trackmodel.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/library/trackmodel.h')
-rw-r--r--src/library/trackmodel.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/library/trackmodel.h b/src/library/trackmodel.h
index c4614a2385..4516630c28 100644
--- a/src/library/trackmodel.h
+++ b/src/library/trackmodel.h
@@ -7,6 +7,7 @@
#include <QtSql>
#include "track/track.h"
+#include "track/trackref.h"
#include "library/dao/settingsdao.h"
/** Pure virtual (abstract) class that provides an interface for data models which
@@ -86,9 +87,10 @@ class TrackModel {
NUM_SORTCOLUMNIDS
};
// Deserialize and return the track at the given QModelIndex in this result
// set.
virtual TrackPointer getTrack(const QModelIndex& index) const = 0;
+ virtual TrackPointer getTrackByRef(const TrackRef& trackRef) const = 0;
// Gets the on-disk location of the track at the given location
// with Qt separator "/".
@@ -86,9 +87,10 @@ class TrackModel {
NUM_SORTCOLUMNIDS
};
- // Deserialize and return the track at the given QModelIndex in this result
- // set.
+ // Deserialize and return the track at the given QModelIndex
+ // or TrackRef in this result set.
virtual TrackPointer getTrack(const QModelIndex& index) const = 0;